'use strict';
const _ = require('lodash');
const { CrudService } = require('naf-framework-mongoose/lib/service');

class UtilService extends CrudService {
  constructor(ctx) {
    super(ctx);
    this.mq = this.ctx.mq;
  }
  async utilMethod(query, body) {
    console.log(query, body);
  }
  /**
   * 获取字段前置函数
   * @param {String} param0 {model字段名
   */
  async findModel({ model }) {
    if (model !== 'all') return await this.getModel(model);
    const modelList = this.ctx.model;
    const keys = Object.keys(modelList);
    const arr = [];
    for (const key of keys) {
      if (key !== 'Test') {
        const zh = this.modelToZh(key);
        if (!zh) continue;
        arr.push({
          zh,
          table: key,
          value: await this.getModel(key),
        });
      }
    }
    return arr;
  }

  /**
   * 获取字段
   * @param {String} model 表名
   */
  async getModel(model) {
    const _model = _.capitalize(model);
    const data = this.ctx.model[_model].prototype.schema.obj;
    const keys = Object.keys(data);
    let res = [];
    for (const k of keys) {
      const field = _.get(data[k], 'field');
      if (field && _.get(field, 'label')) {
        field.model = k;
        res.push(field);
      }
    }
    res = _.orderBy(res, [ 'row' ], [ 'asc' ]);
    return res;
  }

  /**
   * 表名换成中文
   * @param {String} model 表名
   */
  modelToZh(model) {
    const obj = {
      car: '车辆表',
      client: '客户/供应商表',
      daily: '车辆日常维修表',
      dictionary: '字典表',
      driver: '司机表',
      item: '项目表',
      mode: '计费方式表',
      order: '订单表',
      route: '路线表',
      transport: '运输表',
      treaty: '合同表',
    };
    return obj[_.lowerCase(model)];
  }
  /**
   * 将查询条件中模糊查询的标识转换成对应object
   * @param {Object} filter 查询条件
   */
  turnFilter(filter) {
    const str = /^%\w*%$/;
    const keys = Object.keys(filter);
    for (const key of keys) {
      const res = key.match(str);
      if (res) {
        const newKey = key.slice(1, key.length - 1);
        filter[newKey] = new RegExp(filter[key]);
        delete filter[key];
      }
    }
    return filter;
  }
  /**
   * 将时间转换成对应查询Object
   * @param {Object} filter 查询条件
   */
  turnDateRangeQuery(filter) {
    const keys = Object.keys(filter);
    for (const k of keys) {
      if (k.includes('@')) {
        const karr = k.split('@');
        //  因为是针对处理范围日期,所以必须只有,开始时间和结束时间
        if (karr.length === 2) {
          const type = karr[1];
          if (type === 'start') {
            filter[karr[0]] = {
              ..._.get(filter, karr[0], {}),
              $gte: filter[k],
            };
          } else {
            filter[karr[0]] = {
              ..._.get(filter, karr[0], {}),
              $lte: filter[k],
            };
          }
          delete filter[k];
        }
      }
    }
    return filter;
  }
}
module.exports = UtilService;
